from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class DslPools(Base):
	"""Represents an Access Loop connected to a DSLAM running ANCP
	"""

	_SDM_NAME = 'dslPools'

	def __init__(self, parent):
		super(DslPools, self).__init__(parent)

	def Connector(self, ConnectedTo=None, Count=None, PropagateMultiplier=None):
		"""Gets child instances of Connector from the server.

		Use the named parameters as selection criteria to find specific instances.
		All named parameters support regex.
		If no named parameters are specified then all instances of Connector will be returned.

		Args:
			ConnectedTo (str(None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*)): Scenario element this connector is connecting to
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group
			PropagateMultiplier (bool): The Connector will propagate the multiplicity of destination back to the source and its parent NetworkElementSet

		Returns:
			list(obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.connector.Connector))

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.connector import Connector
		return self._select(Connector(self), locals())

	def add_Connector(self, ConnectedTo=None):
		"""Adds a child instance of Connector on the server.

		Args:
			ConnectedTo (str(None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*)): Scenario element this connector is connecting to

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.connector.Connector)

		Raises:
			AlreadyExistsError: The requested resource already exists on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.connector import Connector
		return self._create(Connector(self), locals())

	def TlvProfile(self):
		"""Gets child instances of TlvProfile from the server.

		Use the named parameters as selection criteria to find specific instances.
		All named parameters support regex.
		If no named parameters are specified then all instances of TlvProfile will be returned.

		Returns:
			list(obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tlvprofile.tlvprofile.TlvProfile))

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tlvprofile.tlvprofile import TlvProfile
		return self._select(TlvProfile(self), locals())

	@property
	def ActualBandwidthDownstream(self):
		"""Subscriber Line Actual Bandwidth Downstream

		Returns:
			list(number)
		"""
		return self._get_attribute('actualBandwidthDownstream')

	@property
	def ActualBandwidthUpstream(self):
		"""Subscriber Line Actual Bandwidth Upstream

		Returns:
			list(number)
		"""
		return self._get_attribute('actualBandwidthUpstream')

	@property
	def ActualNetDataRateDownstream(self):
		"""Actual downstream net data rate on a DSL access line. Rate in kbits/s as a 32-bit unsigned integer

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('actualNetDataRateDownstream')

	@property
	def ActualNetDataRateDownstreamTolerance(self):
		"""Percentage for variation of Actual Net Data Rate Downstream TLV value when sending port-up messages in flapping behavior

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('actualNetDataRateDownstreamTolerance')

	@property
	def ActualNetDataRateUpstream(self):
		"""Actual upstream net data rate on a DSL access line. Rate in kbits/s as a 32-bit unsigned integer

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('actualNetDataRateUpstream')

	@property
	def ActualNetDataRateUpstreamTolerance(self):
		"""Percentage for variation of Actual Net Data Rate Upstream TLV value when sending port-up messages in flapping behavior

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('actualNetDataRateUpstreamTolerance')

	@property
	def CircuitId(self):
		"""A locally administered human-readable string generated by or configured on the Access Node, identifying the corresponding access loop logical port on the user side of the Access Node

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('circuitId')

	@property
	def Count(self):
		"""Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DescriptiveName(self):
		"""Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def DslLineState(self):
		"""The state of the DSL line as defined in DSL Line State TLV SHOWTIME - Status Info TLV has value 1 IDLE - Status Info TLV has value 2 SILENT - Status Info TLV has value 3 TLV N/A - Status Info TLV was not configured for this message None - The DSL Line did not send any messages Disabled - The DSL Line is disabled

		Returns:
			list(str[disabled|idle|none|showTime|silent|tlvNa])
		"""
		return self._get_attribute('dslLineState')

	@property
	def DslType(self):
		"""DSL Type value for DSL Type TLV

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('dslType')

	@property
	def EnableActualNetDataRateDownstream(self):
		"""Enable Actual-Net-Data-Rate-Downstream TLV

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableActualNetDataRateDownstream')

	@property
	def EnableActualNetDataRateUpstream(self):
		"""Enable Actual-Net-Data-Rate-Upstream TLV

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableActualNetDataRateUpstream')

	@property
	def EnableDslType(self):
		"""Enable DSL Type TLV

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableDslType')

	@property
	def EnablePonType(self):
		"""Enable PON Type TLV

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enablePonType')

	@property
	def EnableRemoteId(self):
		"""Enable Access-Loop-Remote-ID TLV

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableRemoteId')

	@property
	def FlappingMode(self):
		"""Enable a flapping profile. Resync will send Port-Up messages, one message every 'Flap Interval' seconds. Reset will send Port-Up followed by Port-Down messages, one message every 'Flap Interval' seconds. Stop will stop the flapping profile, and send one Port-Up message if the line is silent at the time of stopping the flapping profile.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('flappingMode')

	@property
	def InnerVlanId(self):
		"""Inner VLAN ID for N:1 and 1:1 VLAN mapping in Access-Aggregation-Circuit-ID-Binary TLV

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('innerVlanId')

	@property
	def LineDownInterval(self):
		"""Interval in milliseconds to wait after sending port-down message when flapping is enabled

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('lineDownInterval')

	@property
	def LineUpInterval(self):
		"""Interval in milliseconds to wait after sending port-up message when flapping is enabled

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('lineUpInterval')

	@property
	def Name(self):
		"""Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def OuterVlanId(self):
		"""Outer VLAN ID for 1:1 VLAN mapping in Access-Aggregation-Circuit-ID-Binary TLV

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('outerVlanId')

	@property
	def PonType(self):
		"""PON Type value for PON Type TLV

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ponType')

	@property
	def PortDownSent(self):
		"""Number of Topology Discovery Port Down messages sent

		Returns:
			list(number)
		"""
		return self._get_attribute('portDownSent')

	@property
	def PortUpSent(self):
		"""Number of Topology Discovery Port Up messages sent

		Returns:
			list(number)
		"""
		return self._get_attribute('portUpSent')

	@property
	def RemoteId(self):
		"""An operator-configured string that uniquely identifies the user on the associated access line

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('remoteId')

	@property
	def TechType(self):
		"""Type of Access Loop Technology

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('techType')

	@property
	def VlanAllocationModel(self):
		"""Access-Aggregation-Circuit-ID-Binary TLV disable, enable N:1 vlan allocation model or 1:1 vlan allocation model

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('vlanAllocationModel')

	def remove(self):
		"""Deletes a child instance of DslPools on the server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def FetchAndUpdateConfigFromCloud(self, Mode):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		Args:
			Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		Arg1 = self.href
		return self._execute('fetchAndUpdateConfigFromCloud', payload=locals(), response_object=None)
