from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class OpenFlowController(Base):
	"""OpenFlow Session (Device) level Configuration
	"""

	_SDM_NAME = 'openFlowController'

	def __init__(self, parent):
		super(OpenFlowController, self).__init__(parent)

	def LearnedInfo(self, State=None, Type=None):
		"""Gets child instances of LearnedInfo from the server.

		Use the named parameters as selection criteria to find specific instances.
		All named parameters support regex.
		If no named parameters are specified then all instances of LearnedInfo will be returned.

		Args:
			State (str): The state of the learned information query
			Type (str): The type of learned information

		Returns:
			list(obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.learnedinfo.LearnedInfo))

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.learnedinfo import LearnedInfo
		return self._select(LearnedInfo(self), locals())

	def LearnedInfoUpdate(self):
		"""Gets child instances of LearnedInfoUpdate from the server.

		Use the named parameters as selection criteria to find specific instances.
		All named parameters support regex.
		If no named parameters are specified then all instances of LearnedInfoUpdate will be returned.

		Returns:
			list(obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.learnedinfoupdate.LearnedInfoUpdate))

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.learnedinfoupdate import LearnedInfoUpdate
		return self._select(LearnedInfoUpdate(self), locals())

	def OpenFlowChannel(self, Active=None, CalcFlowRate=None, CalcFlowRateWithBarrier=None, ControllerName=None, Count=None, DatapathId=None, DatapathIdHex=None, DescriptiveName=None, EnableHelloElement=None, FlowTxBurstSize=None, GroupsPerChannel=None, InterFlowBurstGap=None, MaxFlowsAtATime=None, MetersPerChannel=None, Multiplier=None, Name=None, RemoteIp=None, SendRoleRequest=None, StartupGenerationId=None, StartupRoleRequest=None, Status=None, TablesPerChannel=None, UseDatapathID=None):
		"""Gets child instances of OpenFlowChannel from the server.

		Use the named parameters as selection criteria to find specific instances.
		All named parameters support regex.
		If no named parameters are specified then all instances of OpenFlowChannel will be returned.

		Args:
			Active (obj(ixnetwork_restpy.multivalue.Multivalue)): Activate/Deactivate Configuration
			CalcFlowRate (obj(ixnetwork_restpy.multivalue.Multivalue)): If selected, the statistics on the rate of transmission of flows per second by the controller is published.
			CalcFlowRateWithBarrier (obj(ixnetwork_restpy.multivalue.Multivalue)): If selected, statistics on the rate of transmission of flows per second by the controller, along with Barrier Request messages is published.
			ControllerName (str): Parent Controller Name
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group
			DatapathId (obj(ixnetwork_restpy.multivalue.Multivalue)): The Datapath ID of the OF Channel.
			DatapathIdHex (obj(ixnetwork_restpy.multivalue.Multivalue)): The Datapath ID in hexadecimal format.
			DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context
			EnableHelloElement (obj(ixnetwork_restpy.multivalue.Multivalue)): If selected, the Controller sends a hello message consisting of an OpenFlow header and a set of variable size hello elements to inform the initial handshake of the connection.
			FlowTxBurstSize (obj(ixnetwork_restpy.multivalue.Multivalue)): Specify the number of Flow transmitting packets that can be sent in a single burst within the time frame specified by the Inter Flow Burst Gap value.
			GroupsPerChannel (number): Number of Groups per Channel
			InterFlowBurstGap (obj(ixnetwork_restpy.multivalue.Multivalue)): Specify the duration (in milliseconds) for which the controller waits between successive flow advertisements.
			MaxFlowsAtATime (obj(ixnetwork_restpy.multivalue.Multivalue)): The Max Number of Flows Processed at a Time is the size of an internal buffer maintained by the Ixiacontroller, which prevents it from sending more flows than the Openflow switch can consume at a time.
			MetersPerChannel (number): Number of Meters per Channel
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			RemoteIp (obj(ixnetwork_restpy.multivalue.Multivalue)): The IP address of the DUT at the other end of the OF Channel.
			SendRoleRequest (obj(ixnetwork_restpy.multivalue.Multivalue)): If selected, the controller sends a Role Request message after the connection is established; to change its role according to the Role Request option selected.
			StartupGenerationId (obj(ixnetwork_restpy.multivalue.Multivalue)): A 64-bit sequence number field that identifies a given mastership view.
			StartupRoleRequest (obj(ixnetwork_restpy.multivalue.Multivalue)): This defines role of the controller.Options include: 1) No Change 2) Equal 3) Master 4) Slave
			Status (str(configured|error|mixed|notStarted|started|starting|stopping)): Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.
			TablesPerChannel (number): Number of Tables per Channel
			UseDatapathID (obj(ixnetwork_restpy.multivalue.Multivalue)): If selected, the Datapath ID and IP address are used as the OF Channel identifier.

		Returns:
			list(obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.openflowchannel.OpenFlowChannel))

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.openflowchannel import OpenFlowChannel
		return self._select(OpenFlowChannel(self), locals())

	def add_OpenFlowChannel(self, ConnectedVia=None, GroupsPerChannel="0", MetersPerChannel="0", Multiplier="1", Name=None, StackedLayers=None, TablesPerChannel="1"):
		"""Adds a child instance of OpenFlowChannel on the server.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			GroupsPerChannel (number): Number of Groups per Channel
			MetersPerChannel (number): Number of Meters per Channel
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols
			TablesPerChannel (number): Number of Tables per Channel

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.openflowchannel.OpenFlowChannel)

		Raises:
			AlreadyExistsError: The requested resource already exists on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.openflowchannel import OpenFlowChannel
		return self._create(OpenFlowChannel(self), locals())

	def GetAsynchronousConfiguration(self, Arg1):
		"""Executes the getAsynchronousConfiguration operation on the server.

		Get Asynchronous Configurationr

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('getAsynchronousConfiguration', child='openFlowChannel', payload=locals(), response_object=None)

	def GetAsynchronousConfiguration(self, Arg1, SessionIndices):
		"""Executes the getAsynchronousConfiguration operation on the server.

		Get Asynchronous Configurationr

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('getAsynchronousConfiguration', child='openFlowChannel', payload=locals(), response_object=None)

	def GetAsynchronousConfiguration(self, Arg1, SessionIndices):
		"""Executes the getAsynchronousConfiguration operation on the server.

		Get Asynchronous Configurationr

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('getAsynchronousConfiguration', child='openFlowChannel', payload=locals(), response_object=None)

	def PauseEchoReply(self, Arg1):
		"""Executes the pauseEchoReply operation on the server.

		Pause Sending Echo Reply Messages

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('pauseEchoReply', child='openFlowChannel', payload=locals(), response_object=None)

	def PauseEchoReply(self, Arg1, SessionIndices):
		"""Executes the pauseEchoReply operation on the server.

		Pause Sending Echo Reply Messages

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('pauseEchoReply', child='openFlowChannel', payload=locals(), response_object=None)

	def PauseEchoReply(self, Arg1, SessionIndices):
		"""Executes the pauseEchoReply operation on the server.

		Pause Sending Echo Reply Messages

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('pauseEchoReply', child='openFlowChannel', payload=locals(), response_object=None)

	def PauseEchoRequest(self, Arg1):
		"""Executes the pauseEchoRequest operation on the server.

		Pause Sending Echo Request Messages

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('pauseEchoRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def PauseEchoRequest(self, Arg1, SessionIndices):
		"""Executes the pauseEchoRequest operation on the server.

		Pause Sending Echo Request Messages

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('pauseEchoRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def PauseEchoRequest(self, Arg1, SessionIndices):
		"""Executes the pauseEchoRequest operation on the server.

		Pause Sending Echo Request Messages

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('pauseEchoRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def RestartDown(self, Arg1):
		"""Executes the restartDown operation on the server.

		Stop and start interfaces and sessions that are in Down state.

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('restartDown', child='openFlowChannel', payload=locals(), response_object=None)

	def RestartDown(self, Arg1, SessionIndices):
		"""Executes the restartDown operation on the server.

		Stop and start interfaces and sessions that are in Down state.

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('restartDown', child='openFlowChannel', payload=locals(), response_object=None)

	def RestartDown(self, Arg1, SessionIndices):
		"""Executes the restartDown operation on the server.

		Stop and start interfaces and sessions that are in Down state.

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('restartDown', child='openFlowChannel', payload=locals(), response_object=None)

	def ResumeEchoReply(self, Arg1):
		"""Executes the resumeEchoReply operation on the server.

		Resume Sending Echo Reply Messages

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('resumeEchoReply', child='openFlowChannel', payload=locals(), response_object=None)

	def ResumeEchoReply(self, Arg1, SessionIndices):
		"""Executes the resumeEchoReply operation on the server.

		Resume Sending Echo Reply Messages

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('resumeEchoReply', child='openFlowChannel', payload=locals(), response_object=None)

	def ResumeEchoReply(self, Arg1, SessionIndices):
		"""Executes the resumeEchoReply operation on the server.

		Resume Sending Echo Reply Messages

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('resumeEchoReply', child='openFlowChannel', payload=locals(), response_object=None)

	def ResumeEchoRequest(self, Arg1):
		"""Executes the resumeEchoRequest operation on the server.

		Resume Sending Echo Request Messages

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('resumeEchoRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def ResumeEchoRequest(self, Arg1, SessionIndices):
		"""Executes the resumeEchoRequest operation on the server.

		Resume Sending Echo Request Messages

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('resumeEchoRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def ResumeEchoRequest(self, Arg1, SessionIndices):
		"""Executes the resumeEchoRequest operation on the server.

		Resume Sending Echo Request Messages

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('resumeEchoRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendBarrierRequest(self, Arg1):
		"""Executes the sendBarrierRequest operation on the server.

		Send Barrier Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendBarrierRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendBarrierRequest(self, Arg1, SessionIndices):
		"""Executes the sendBarrierRequest operation on the server.

		Send Barrier Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendBarrierRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendBarrierRequest(self, Arg1, SessionIndices):
		"""Executes the sendBarrierRequest operation on the server.

		Send Barrier Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendBarrierRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendConfigRequest(self, Arg1):
		"""Executes the sendConfigRequest operation on the server.

		Send Config Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendConfigRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendConfigRequest(self, Arg1, SessionIndices):
		"""Executes the sendConfigRequest operation on the server.

		Send Config Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendConfigRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendConfigRequest(self, Arg1, SessionIndices):
		"""Executes the sendConfigRequest operation on the server.

		Send Config Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendConfigRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendDescriptionStatRequest(self, Arg1):
		"""Executes the sendDescriptionStatRequest operation on the server.

		Send Description Stat Request

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendDescriptionStatRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendDescriptionStatRequest(self, Arg1, SessionIndices):
		"""Executes the sendDescriptionStatRequest operation on the server.

		Send Description Stat Request

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendDescriptionStatRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendDescriptionStatRequest(self, Arg1, SessionIndices):
		"""Executes the sendDescriptionStatRequest operation on the server.

		Send Description Stat Request

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendDescriptionStatRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendEchoRequest(self, Arg1, EnableEchoTimeout, EchoTimeoutVal):
		"""Executes the sendEchoRequest operation on the server.

		Send Echo Request

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			EnableEchoTimeout (bool): This parameter requires a enableEchoTimeout of type kBool
			EchoTimeoutVal (number): This parameter requires a echoTimeoutVal of type kInteger

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendEchoRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendEchoRequest(self, Arg1, EnableEchoTimeout, EchoTimeoutVal, SessionIndices):
		"""Executes the sendEchoRequest operation on the server.

		Send Echo Request

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			EnableEchoTimeout (bool): This parameter requires a enableEchoTimeout of type kBool
			EchoTimeoutVal (number): This parameter requires a echoTimeoutVal of type kInteger
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendEchoRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendEchoRequest(self, Arg1, SessionIndices, EnableEchoTimeout, EchoTimeoutVal):
		"""Executes the sendEchoRequest operation on the server.

		Send Echo Request

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a enableEchoTimeout of type kBool
			EnableEchoTimeout (bool): This parameter requires a echoTimeoutVal of type kInteger
			EchoTimeoutVal (number): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendEchoRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendFeatureRequest(self, Arg1):
		"""Executes the sendFeatureRequest operation on the server.

		Send Feature Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendFeatureRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendFeatureRequest(self, Arg1, SessionIndices):
		"""Executes the sendFeatureRequest operation on the server.

		Send Feature Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendFeatureRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendFeatureRequest(self, Arg1, SessionIndices):
		"""Executes the sendFeatureRequest operation on the server.

		Send Feature Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendFeatureRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendGetQueueConfigRequest(self, Arg1, OutputPortType, ErrorUnsupportedTypeFormat):
		"""Executes the sendGetQueueConfigRequest operation on the server.

		Send Queue Stats Request

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			OutputPortType (str(enumOpt-MANUAL|enumOpt-OFPP_ANY)): This parameter requires a outputPortType of type kEnumValue=enumOpt-MANUAL,enumOpt-OFPP_ANY
			ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendGetQueueConfigRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendGetQueueConfigRequest(self, Arg1, OutputPortType, ErrorUnsupportedTypeFormat, SessionIndices):
		"""Executes the sendGetQueueConfigRequest operation on the server.

		Send Queue Stats Request

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			OutputPortType (str(enumOpt-MANUAL|enumOpt-OFPP_ANY)): This parameter requires a outputPortType of type kEnumValue=enumOpt-MANUAL,enumOpt-OFPP_ANY
			ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendGetQueueConfigRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendGetQueueConfigRequest(self, Arg1, SessionIndices, OutputPortType, ErrorUnsupportedTypeFormat):
		"""Executes the sendGetQueueConfigRequest operation on the server.

		Send Queue Stats Request

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a outputPortType of type kEnumValue=enumOpt-MANUAL,enumOpt-OFPP_ANY
			OutputPortType (str(enumOpt-MANUAL|enumOpt-OFPP_ANY)): This parameter requires a errorUnsupportedTypeFormat of type kVoid
			ErrorUnsupportedTypeFormat (null): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendGetQueueConfigRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendGroupDescriptionRequest(self, Arg1):
		"""Executes the sendGroupDescriptionRequest operation on the server.

		Send Group Description Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendGroupDescriptionRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendGroupDescriptionRequest(self, Arg1, SessionIndices):
		"""Executes the sendGroupDescriptionRequest operation on the server.

		Send Group Description Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendGroupDescriptionRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendGroupDescriptionRequest(self, Arg1, SessionIndices):
		"""Executes the sendGroupDescriptionRequest operation on the server.

		Send Group Description Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendGroupDescriptionRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendGroupFeaturesRequest(self, Arg1):
		"""Executes the sendGroupFeaturesRequest operation on the server.

		Send Group Features Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendGroupFeaturesRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendGroupFeaturesRequest(self, Arg1, SessionIndices):
		"""Executes the sendGroupFeaturesRequest operation on the server.

		Send Group Features Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendGroupFeaturesRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendGroupFeaturesRequest(self, Arg1, SessionIndices):
		"""Executes the sendGroupFeaturesRequest operation on the server.

		Send Group Features Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendGroupFeaturesRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendGroupStatsRequest(self, Arg1, GroupIDType, GroupID):
		"""Executes the sendGroupStatsRequest operation on the server.

		Send Group Stats Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			GroupIDType (str(enumOpt-Manual|enumOpt-OFPG_ALL|enumOpt-OFPG_ANY)): This parameter requires a groupIDType of type kEnumValue=enumOpt-Manual,enumOpt-OFPG_ALL,enumOpt-OFPG_ANY
			GroupID (number): This parameter requires a groupID of type kInteger

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendGroupStatsRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendGroupStatsRequest(self, Arg1, GroupIDType, GroupID, SessionIndices):
		"""Executes the sendGroupStatsRequest operation on the server.

		Send Group Stats Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			GroupIDType (str(enumOpt-Manual|enumOpt-OFPG_ALL|enumOpt-OFPG_ANY)): This parameter requires a groupIDType of type kEnumValue=enumOpt-Manual,enumOpt-OFPG_ALL,enumOpt-OFPG_ANY
			GroupID (number): This parameter requires a groupID of type kInteger
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendGroupStatsRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendGroupStatsRequest(self, Arg1, SessionIndices, GroupIDType, GroupID):
		"""Executes the sendGroupStatsRequest operation on the server.

		Send Group Stats Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a groupIDType of type kEnumValue=enumOpt-Manual,enumOpt-OFPG_ALL,enumOpt-OFPG_ANY
			GroupIDType (str(enumOpt-Manual|enumOpt-OFPG_ALL|enumOpt-OFPG_ANY)): This parameter requires a groupID of type kInteger
			GroupID (number): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendGroupStatsRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendMeterConfigRequest(self, Arg1, MeterIDType, ErrorUnsupportedTypeFormat):
		"""Executes the sendMeterConfigRequest operation on the server.

		Send Meter Config Request

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			MeterIDType (str(enumOpt-ALL|enumOpt-MANUAL|enumOpt-OFPM_CONTROLLER|enumOpt-OFPM_SLOWPATH)): This parameter requires a meterIDType of type kEnumValue=enumOpt-ALL,enumOpt-MANUAL,enumOpt-OFPM_CONTROLLER,enumOpt-OFPM_SLOWPATH
			ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendMeterConfigRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendMeterConfigRequest(self, Arg1, MeterIDType, ErrorUnsupportedTypeFormat, SessionIndices):
		"""Executes the sendMeterConfigRequest operation on the server.

		Send Meter Config Request

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			MeterIDType (str(enumOpt-ALL|enumOpt-MANUAL|enumOpt-OFPM_CONTROLLER|enumOpt-OFPM_SLOWPATH)): This parameter requires a meterIDType of type kEnumValue=enumOpt-ALL,enumOpt-MANUAL,enumOpt-OFPM_CONTROLLER,enumOpt-OFPM_SLOWPATH
			ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendMeterConfigRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendMeterConfigRequest(self, Arg1, SessionIndices, MeterIDType, ErrorUnsupportedTypeFormat):
		"""Executes the sendMeterConfigRequest operation on the server.

		Send Meter Config Request

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a meterIDType of type kEnumValue=enumOpt-ALL,enumOpt-MANUAL,enumOpt-OFPM_CONTROLLER,enumOpt-OFPM_SLOWPATH
			MeterIDType (str(enumOpt-ALL|enumOpt-MANUAL|enumOpt-OFPM_CONTROLLER|enumOpt-OFPM_SLOWPATH)): This parameter requires a errorUnsupportedTypeFormat of type kVoid
			ErrorUnsupportedTypeFormat (null): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendMeterConfigRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendMeterFeaturesRequest(self, Arg1):
		"""Executes the sendMeterFeaturesRequest operation on the server.

		Send Meter Features Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendMeterFeaturesRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendMeterFeaturesRequest(self, Arg1, SessionIndices):
		"""Executes the sendMeterFeaturesRequest operation on the server.

		Send Meter Features Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendMeterFeaturesRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendMeterFeaturesRequest(self, Arg1, SessionIndices):
		"""Executes the sendMeterFeaturesRequest operation on the server.

		Send Meter Features Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendMeterFeaturesRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendMeterStatsRequest(self, Arg1, MeterIDType, ErrorUnsupportedTypeFormat):
		"""Executes the sendMeterStatsRequest operation on the server.

		Send Meter Stats Request

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			MeterIDType (str(enumOpt-ALL|enumOpt-MANUAL|enumOpt-OFPM_CONTROLLER|enumOpt-OFPM_SLOWPATH)): This parameter requires a meterIDType of type kEnumValue=enumOpt-ALL,enumOpt-MANUAL,enumOpt-OFPM_CONTROLLER,enumOpt-OFPM_SLOWPATH
			ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendMeterStatsRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendMeterStatsRequest(self, Arg1, MeterIDType, ErrorUnsupportedTypeFormat, SessionIndices):
		"""Executes the sendMeterStatsRequest operation on the server.

		Send Meter Stats Request

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			MeterIDType (str(enumOpt-ALL|enumOpt-MANUAL|enumOpt-OFPM_CONTROLLER|enumOpt-OFPM_SLOWPATH)): This parameter requires a meterIDType of type kEnumValue=enumOpt-ALL,enumOpt-MANUAL,enumOpt-OFPM_CONTROLLER,enumOpt-OFPM_SLOWPATH
			ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendMeterStatsRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendMeterStatsRequest(self, Arg1, SessionIndices, MeterIDType, ErrorUnsupportedTypeFormat):
		"""Executes the sendMeterStatsRequest operation on the server.

		Send Meter Stats Request

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a meterIDType of type kEnumValue=enumOpt-ALL,enumOpt-MANUAL,enumOpt-OFPM_CONTROLLER,enumOpt-OFPM_SLOWPATH
			MeterIDType (str(enumOpt-ALL|enumOpt-MANUAL|enumOpt-OFPM_CONTROLLER|enumOpt-OFPM_SLOWPATH)): This parameter requires a errorUnsupportedTypeFormat of type kVoid
			ErrorUnsupportedTypeFormat (null): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendMeterStatsRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendPortDescription(self, Arg1):
		"""Executes the sendPortDescription operation on the server.

		Send Port Description

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendPortDescription', child='openFlowChannel', payload=locals(), response_object=None)

	def SendPortDescription(self, Arg1, SessionIndices):
		"""Executes the sendPortDescription operation on the server.

		Send Port Description

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendPortDescription', child='openFlowChannel', payload=locals(), response_object=None)

	def SendPortDescription(self, Arg1, SessionIndices):
		"""Executes the sendPortDescription operation on the server.

		Send Port Description

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendPortDescription', child='openFlowChannel', payload=locals(), response_object=None)

	def SendPortStatsRequest(self, Arg1, OutputPortType, ErrorUnsupportedTypeFormat):
		"""Executes the sendPortStatsRequest operation on the server.

		Send Port Stats Request

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			OutputPortType (str(enumOpt-MANUAL|enumOpt-OFPP_ANY|enumOpt-OFPP_NONE)): This parameter requires a outputPortType of type kEnumValue=enumOpt-MANUAL,enumOpt-OFPP_ANY,enumOpt-OFPP_NONE
			ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendPortStatsRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendPortStatsRequest(self, Arg1, OutputPortType, ErrorUnsupportedTypeFormat, SessionIndices):
		"""Executes the sendPortStatsRequest operation on the server.

		Send Port Stats Request

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			OutputPortType (str(enumOpt-MANUAL|enumOpt-OFPP_ANY|enumOpt-OFPP_NONE)): This parameter requires a outputPortType of type kEnumValue=enumOpt-MANUAL,enumOpt-OFPP_ANY,enumOpt-OFPP_NONE
			ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendPortStatsRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendPortStatsRequest(self, Arg1, SessionIndices, OutputPortType, ErrorUnsupportedTypeFormat):
		"""Executes the sendPortStatsRequest operation on the server.

		Send Port Stats Request

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a outputPortType of type kEnumValue=enumOpt-MANUAL,enumOpt-OFPP_ANY,enumOpt-OFPP_NONE
			OutputPortType (str(enumOpt-MANUAL|enumOpt-OFPP_ANY|enumOpt-OFPP_NONE)): This parameter requires a errorUnsupportedTypeFormat of type kVoid
			ErrorUnsupportedTypeFormat (null): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendPortStatsRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendTableModRequest(self, Arg1, TableIdType, TableId, ErrorUnsupportedTypeFormat):
		"""Executes the sendTableModRequest operation on the server.

		Send Table Mod Request

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			TableIdType (str(enumOpt-ALL_TABLE|enumOpt-MANUAL)): This parameter requires a tableIdType of type kEnumValue=enumOpt-ALL_TABLE,enumOpt-MANUAL
			TableId (number): This parameter requires a tableId of type kInteger
			ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendTableModRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendTableModRequest(self, Arg1, TableIdType, TableId, ErrorUnsupportedTypeFormat, SessionIndices):
		"""Executes the sendTableModRequest operation on the server.

		Send Table Mod Request

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			TableIdType (str(enumOpt-ALL_TABLE|enumOpt-MANUAL)): This parameter requires a tableIdType of type kEnumValue=enumOpt-ALL_TABLE,enumOpt-MANUAL
			TableId (number): This parameter requires a tableId of type kInteger
			ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendTableModRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendTableModRequest(self, Arg1, SessionIndices, TableIdType, TableId, ErrorUnsupportedTypeFormat):
		"""Executes the sendTableModRequest operation on the server.

		Send Table Mod Request

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a tableIdType of type kEnumValue=enumOpt-ALL_TABLE,enumOpt-MANUAL
			TableIdType (str(enumOpt-ALL_TABLE|enumOpt-MANUAL)): This parameter requires a tableId of type kInteger
			TableId (number): This parameter requires a errorUnsupportedTypeFormat of type kVoid
			ErrorUnsupportedTypeFormat (null): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendTableModRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendTableStatsRequest(self, Arg1):
		"""Executes the sendTableStatsRequest operation on the server.

		Send Table Stats Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendTableStatsRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendTableStatsRequest(self, Arg1, SessionIndices):
		"""Executes the sendTableStatsRequest operation on the server.

		Send Table Stats Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendTableStatsRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def SendTableStatsRequest(self, Arg1, SessionIndices):
		"""Executes the sendTableStatsRequest operation on the server.

		Send Table Stats Request to Switch

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('sendTableStatsRequest', child='openFlowChannel', payload=locals(), response_object=None)

	def Start(self, Arg1):
		"""Executes the start operation on the server.

		Start selected protocols.

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('start', child='openFlowChannel', payload=locals(), response_object=None)

	def Start(self, Arg1, SessionIndices):
		"""Executes the start operation on the server.

		Start selected protocols.

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('start', child='openFlowChannel', payload=locals(), response_object=None)

	def Start(self, Arg1, SessionIndices):
		"""Executes the start operation on the server.

		Start selected protocols.

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('start', child='openFlowChannel', payload=locals(), response_object=None)

	def StartChannel(self, Arg1):
		"""Executes the startChannel operation on the server.

		Start OpenFlow Channel

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('startChannel', child='openFlowChannel', payload=locals(), response_object=None)

	def StartChannel(self, Arg1, SessionIndices):
		"""Executes the startChannel operation on the server.

		Start OpenFlow Channel

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('startChannel', child='openFlowChannel', payload=locals(), response_object=None)

	def StartChannel(self, Arg1, SessionIndices):
		"""Executes the startChannel operation on the server.

		Start OpenFlow Channel

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('startChannel', child='openFlowChannel', payload=locals(), response_object=None)

	def Stop(self, Arg1):
		"""Executes the stop operation on the server.

		Stop selected protocols.

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('stop', child='openFlowChannel', payload=locals(), response_object=None)

	def Stop(self, Arg1, SessionIndices):
		"""Executes the stop operation on the server.

		Stop selected protocols.

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('stop', child='openFlowChannel', payload=locals(), response_object=None)

	def Stop(self, Arg1, SessionIndices):
		"""Executes the stop operation on the server.

		Stop selected protocols.

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('stop', child='openFlowChannel', payload=locals(), response_object=None)

	def StopChannel(self, Arg1):
		"""Executes the stopChannel operation on the server.

		Stop OpenFlow Channel

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('stopChannel', child='openFlowChannel', payload=locals(), response_object=None)

	def StopChannel(self, Arg1, SessionIndices):
		"""Executes the stopChannel operation on the server.

		Stop OpenFlow Channel

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('stopChannel', child='openFlowChannel', payload=locals(), response_object=None)

	def StopChannel(self, Arg1, SessionIndices):
		"""Executes the stopChannel operation on the server.

		Stop OpenFlow Channel

		Args:
			Arg1 (list(str[None|/api/v1/sessions/1/ixnetwork/topology])): This parameter requires a list of /topology/./openFlowChannel object references
			SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._execute('stopChannel', child='openFlowChannel', payload=locals(), response_object=None)

	@property
	def AcceptUnconfiguredChannel(self):
		"""If selected, un-configured channels are accepted for this interface.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('acceptUnconfiguredChannel')

	@property
	def Active(self):
		"""Activate/Deactivate Configuration

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('active')

	@property
	def AuxConnTimeout(self):
		"""The inactive time in milliseconds after which the auxiliary connection will timeout and close.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('auxConnTimeout')

	@property
	def AuxNonHelloStartupOption(self):
		"""Specify the action from the following options for non-hello message when connection is established. The options are: 1) Accept Connection 2) Return Error

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('auxNonHelloStartupOption')

	@property
	def BadVersionErrorAction(self):
		"""Specify the action to be performed when an invalid version error occurs. The options are: 1) Re-send Hello 2) Terminate Connection

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('badVersionErrorAction')

	@property
	def ConnectedVia(self):
		"""List of layers this layer used to connect to the wire

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])
		"""
		return self._get_attribute('connectedVia')
	@ConnectedVia.setter
	def ConnectedVia(self, value):
		self._set_attribute('connectedVia', value)

	@property
	def ControllerLocalIp(self):
		"""The local IP address of the interface. This field is auto-populated and cannot be changed.

		Returns:
			list(str)
		"""
		return self._get_attribute('controllerLocalIp')

	@property
	def Count(self):
		"""Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DelFlowsAtStartup(self):
		"""If selected, Controller sends an OpenFlow delete message (for all wild card entries) at start-up. This deletes all existing flows in the DUT.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('delFlowsAtStartup')

	@property
	def DescriptiveName(self):
		"""Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def DirectoryName(self):
		"""Location of Directory in Client where the Certificate and Key Files are available

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('directoryName')

	@property
	def EchoInterval(self):
		"""The periodic interval in seconds at which the Interface sends Echo Request Packets.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('echoInterval')

	@property
	def EchoTimeOut(self):
		"""If selected, the echo request times out when they have been sent for a specified number of times, or when the time value specified has lapsed, but no response is received

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('echoTimeOut')

	@property
	def Errors(self):
		"""A list of errors that have occurred

		Returns:
			list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))
		"""
		return self._get_attribute('errors')

	@property
	def FeatRequestTimeout(self):
		"""The inactive time in milliseconds after which the feature request will timeout.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('featRequestTimeout')

	@property
	def FeatureRquestTimeoutAction(self):
		"""Specify the action to be performed when a feature request times out. The options are: 1) Re-send Feature Request 2) Terminate Connection

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('featureRquestTimeoutAction')

	@property
	def FileCaCertificate(self):
		"""Browse and upload a CA Certificate file for TLS session.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('fileCaCertificate')

	@property
	def FileCertificate(self):
		"""Browse and upload the certificate file for TLS session.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('fileCertificate')

	@property
	def FilePrivKey(self):
		"""Browse and upload the private key file for TLS session.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('filePrivKey')

	@property
	def InstallFlowForLLDP(self):
		"""If selected, the controller sends add flow to each connected switch in such a way that each switch forwards LLDP packet to all other connected switches.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('installFlowForLLDP')

	@property
	def InstallLLDPFlow(self):
		"""If selected, LLDP Flow is installed.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('installLLDPFlow')

	@property
	def LLDPDestinactionMac(self):
		"""Specify the LLDP Destination MAC address.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('lLDPDestinactionMac')

	@property
	def LldpDstMacAddress(self):
		"""The destination MAC Address for the LLDP packet.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('lldpDstMacAddress')

	@property
	def ModeOfConnection(self):
		"""The mode of connection used for the Interface. Options include: 1) Active 2) Passive 3) Mixed

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('modeOfConnection')

	@property
	def Multiplier(self):
		"""Number of layer instances per parent instance (multiplier)

		Returns:
			number
		"""
		return self._get_attribute('multiplier')
	@Multiplier.setter
	def Multiplier(self, value):
		self._set_attribute('multiplier', value)

	@property
	def Name(self):
		"""Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def NumberOfChannels(self):
		"""Total number of OpenFlow channels to be added for this protocol interface.

		Returns:
			number
		"""
		return self._get_attribute('numberOfChannels')
	@NumberOfChannels.setter
	def NumberOfChannels(self, value):
		self._set_attribute('numberOfChannels', value)

	@property
	def PeriodicEcho(self):
		"""If selected, the Interface sends echo requests periodically to keep the OpenFlow session connected.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('periodicEcho')

	@property
	def PeriodicLLDP(self):
		"""If selected, the interface sends LLDP packets periodically to discover new links.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('periodicLLDP')

	@property
	def PeriodicLLDPInterval(self):
		"""The periodic interval in milliseconds at which the Interface sends LLDP packets.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('periodicLLDPInterval')

	@property
	def ResponseTimeout(self):
		"""The time in milliseconds after which the trigger request times out, if no response is received

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('responseTimeout')

	@property
	def SendPortFeatureAtStartup(self):
		"""If selected, port Description request is sent when the connection is established

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sendPortFeatureAtStartup')

	@property
	def SessionStatus(self):
		"""Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.

		Returns:
			list(str[down|notStarted|up])
		"""
		return self._get_attribute('sessionStatus')

	@property
	def SetAsyncConfig(self):
		"""Un-checked state means getting the async config, Checked means setting asynchronous config with available parameters

		Returns:
			bool
		"""
		return self._get_attribute('setAsyncConfig')
	@SetAsyncConfig.setter
	def SetAsyncConfig(self, value):
		self._set_attribute('setAsyncConfig', value)

	@property
	def SetSwitchConfig(self):
		"""Un-checked state means getting the async config, Checked means setting asynchronous config with available parameters

		Returns:
			bool
		"""
		return self._get_attribute('setSwitchConfig')
	@SetSwitchConfig.setter
	def SetSwitchConfig(self, value):
		self._set_attribute('setSwitchConfig', value)

	@property
	def StackedLayers(self):
		"""List of secondary (many to one) child layer protocols

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])
		"""
		return self._get_attribute('stackedLayers')
	@StackedLayers.setter
	def StackedLayers(self, value):
		self._set_attribute('stackedLayers', value)

	@property
	def StartupEmptyTableFeatureRequest(self):
		"""If selected, the Table Feature Request is sent at start up.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('startupEmptyTableFeatureRequest')

	@property
	def StartupFeatureRequest(self):
		"""If selected, port feature request is sent when the connection is established.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('startupFeatureRequest')

	@property
	def StateCounts(self):
		"""A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up

		Returns:
			dict(total:number,notStarted:number,down:number,up:number)
		"""
		return self._get_attribute('stateCounts')

	@property
	def Status(self):
		"""Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.

		Returns:
			str(configured|error|mixed|notStarted|started|starting|stopping)
		"""
		return self._get_attribute('status')

	@property
	def TcpPort(self):
		"""Specify the TCP port for this interface

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('tcpPort')

	@property
	def TimeoutOption(self):
		"""The types of timeout options supported. Choose one of the following: 1) Multiplier 2) Timeout Value

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('timeoutOption')

	@property
	def TimeoutOptionValue(self):
		"""The value specified for the selected Timeout option.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('timeoutOptionValue')

	@property
	def TlsVersion(self):
		"""TLS version selection

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('tlsVersion')

	@property
	def TriggerLldp(self):
		"""If selected, LLDP is triggered

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('triggerLldp')

	@property
	def TypeOfConnection(self):
		"""The type of connection used for the Interface. Options include: 1) TCP 2) TLS

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('typeOfConnection')

	@property
	def Version(self):
		"""Implementation Version

		Returns:
			number
		"""
		return self._get_attribute('version')

	@property
	def VersionSupported(self):
		"""Indicates the supported OpenFlow version number.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('versionSupported')

	def remove(self):
		"""Deletes a child instance of OpenFlowController on the server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def ClearAllLearnedInfo(self, Arg2):
		"""Executes the clearAllLearnedInfo operation on the server.

		Clear OF Channels learnt by this Controller.

		Args:
			Arg2 (list(number)): List of OF Channel into the protocol plugin. An empty list indicates all instances in the plugin.

		Returns:
			list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		Arg1 = self.href
		return self._execute('clearAllLearnedInfo', payload=locals(), response_object=None)

	def FetchAndUpdateConfigFromCloud(self, Mode):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		Args:
			Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		Arg1 = self.href
		return self._execute('fetchAndUpdateConfigFromCloud', payload=locals(), response_object=None)

	def GetOFChannelLearnedInfo(self, Arg2):
		"""Executes the getOFChannelLearnedInfo operation on the server.

		Gets OF Channels learnt by this Controller.

		Args:
			Arg2 (list(number)): List of OF Channel into the protocol plugin. An empty list indicates all instances in the plugin.

		Returns:
			list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		Arg1 = self.href
		return self._execute('getOFChannelLearnedInfo', payload=locals(), response_object=None)

	def GetOFTopologyLearnedInfo(self, Arg2):
		"""Executes the getOFTopologyLearnedInfo operation on the server.

		Gets OF Topology learnt by this Controller.

		Args:
			Arg2 (list(number)): List of OF session into the protocol plugin. An empty list indicates all instances in the plugin.

		Returns:
			list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		Arg1 = self.href
		return self._execute('getOFTopologyLearnedInfo', payload=locals(), response_object=None)

	def SendLLDPPacketOut(self, Arg2, Arg3, Arg4, Arg5):
		"""Executes the sendLLDPPacketOut operation on the server.

		Send LLDP Packet Out to all Switches.

		Args:
			Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.
			Arg3 (str): LLDP Destination MAC
			Arg4 (bool): Enable LLDP Flow Add in Switch
			Arg5 (number): LLDP Timeout Value

		Returns:
			list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		Arg1 = self.href
		return self._execute('sendLLDPPacketOut', payload=locals(), response_object=None)
